==> haskell-yesod-1.6.2.1-352-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-Lk9eQU9cDGk8YJqkEYDZga
key:                  yesod-1.6.2.1-Lk9eQU9cDGk8YJqkEYDZga
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  b07ba9310e953de3dc1552110352f1f5
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-Lk9eQU9cDGk8YJqkEYDZga
depends:
    aeson-2.1.2.1-6jLf9XnWqJCFwZgyNgcXK5 base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-D5gtRvoNCm9CE8oOCirzgp
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc directory-1.3.7.1
    fast-logger-3.2.3-4NdW6jDche5KKxE8RhUYuM
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    monad-logger-0.3.42-7eQu6bLB9NPGjNFnm5TdlT
    shakespeare-2.1.3-ANxigkgQuYSAnC1WVqHVhH
    streaming-commons-0.2.3.0-1XHu7gUV9reHz4iwK8W2NW
    template-haskell-2.19.0.0 text-2.0.2 unix-2.7.3
    unordered-containers-0.2.20-C8J7H3CMcSh2WWoYFsvixL
    wai-3.2.4-GkAgRndw8GD5izH5EiTLmD
    wai-extra-3.1.17-4UlPkHOh02YGWpDHiLLkBM
    wai-logger-2.5.0-KOPsu2u65HRBo0wTkU96Z3
    warp-3.3.30-3ExkHsWF0tBAlF0u8CRue4
    yaml-0.11.11.2-5pvBzd2XRRgCshszG7rrpH
    yesod-core-1.6.27.1-2kQjhO5SWVXJh0IFdYmn2s
    yesod-form-1.7.9-CcsLOslt3aEFYT65Sqm6Q
    yesod-persistent-1.6.0.8-F5674rBzxEmFv0wWH7Z1Hm

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.6.2.1-354-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-4IaTPirHZpbKShgImcinuh
key:                  yesod-1.6.2.1-4IaTPirHZpbKShgImcinuh
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  34c30e02444de16454ec26a085f4db84
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-4IaTPirHZpbKShgImcinuh
depends:
    aeson-2.1.2.1-5gViDrHjeNhDfT19MwgeMT base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-FVLYIXkx9NyFPBDwnE2wvC
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc directory-1.3.7.1
    fast-logger-3.2.3-EynU4MfMsHVFyzHM1b4WJJ
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    monad-logger-0.3.42-KyDdKQP2CAc8yW9eHzTJL5
    shakespeare-2.1.3-GoTg67v0qMu7Yk8hG19VVQ
    streaming-commons-0.2.3.0-34wBwxBZPl06oHoRiEv8KR
    template-haskell-2.19.0.0 text-2.0.2 unix-2.7.3
    unordered-containers-0.2.20-BooESfmG3DbHMU6mBvbzIL
    wai-3.2.4-41iNGcJSwNvEUgUKaMQRRA
    wai-extra-3.1.17-8nCNR940FkpGdBLxLOLRvO
    wai-logger-2.5.0-76EjVeqnyiDIz9HJaMAGG4
    warp-3.3.30-KUCEwGn4TuyLVm9l2BLxF8
    yaml-0.11.11.2-2xyl6vgLYjLLxSjbPATLZ7
    yesod-core-1.6.27.1-4dPOXVEtJi3ATIF07NpRVD
    yesod-form-1.7.9-COYz10Q2Oy76sStqybtn43
    yesod-persistent-1.6.0.8-F0g0fk0HoOh8WjAjJBAgkg

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
